@@ -1,11 +1,9 @@
-import re
-from typing import Iterator
-from pregex.exceptions import NonPositiveArgumentException, NegativeArgumentException, \
-    NeitherStringNorPregexException, MinGreaterThanMaxException, InvalidCapturingGroupNameException, \
-    NonStringArgumentException, NonIntegerArgumentException
-
+import re as _re
+import pregex.exceptions as _exceptions
+from typing import Iterator as _Iterator
 
 class Pregex():
+    
     '''
     This class constitutes the basis for every other "Pregex" subclass.
     '''
@@ -13,7 +11,7 @@ class Pregex():
     '''
     The totality of active flags.
     '''
-    __flags: re.RegexFlag = re.MULTILINE | re.DOTALL
+    __flags: _re.RegexFlag = _re.MULTILINE | _re.DOTALL
 
 
     def __init__(self, pattern: str, group_on_concat=False, group_on_quantify=False) -> 'Pregex':
@@ -29,7 +27,7 @@ class Pregex():
         self.__pattern: str = pattern
         self.__group_on_concat: bool = group_on_concat
         self.__group_on_quantify: bool = group_on_quantify
-        self.__compiled: re.Pattern = None
+        self.__compiled: _re.Pattern = None
 
 
     '''
@@ -51,7 +49,7 @@ class Pregex():
         Compiles the underlying RegEx pattern. After invoking this method, \
         any attempt at matching a string will use the compiled RegEx pattern.
         '''
-        self.__compiled = re.compile(self.__pattern, flags=self.__flags)
+        self.__compiled = _re.compile(self.__pattern, flags=self.__flags)
 
     def has_match(self, text: str) -> bool:
         '''
@@ -59,7 +57,7 @@ class Pregex():
 
         :param str text: The piece of text that is to be matched.
         '''
-        return bool(re.search(self.__pattern, text) if self.__compiled is None \
+        return bool(_re.search(self.__pattern, text) if self.__compiled is None \
             else self.__compiled.search(text, flags=self.__flags))
 
     def is_exact_match(self, text: str) -> bool:
@@ -68,10 +66,10 @@ class Pregex():
 
         :param str text: The piece of text that is to be matched.
         '''
-        return bool(re.fullmatch(self.__pattern, text, flags=self.__flags) \
+        return bool(_re.fullmatch(self.__pattern, text, flags=self.__flags) \
             if self.__compiled is None else self.__compiled.fullmatch(text))
 
-    def iterate_matches(self, text: str) -> Iterator[str]:
+    def iterate_matches(self, text: str) -> _Iterator[str]:
         '''
         Generates any possible matches with 'text' one by one.
 
@@ -80,7 +78,7 @@ class Pregex():
         for match in self.__iterate_match_objects(text):
             yield match.group(0)
 
-    def iterate_matches_and_pos(self, text: str) -> Iterator[tuple[str, int, int]]:
+    def iterate_matches_and_pos(self, text: str) -> _Iterator[tuple[str, int, int]]:
         '''
         Generates any possible matches with 'text' one by one, \
         along with their exact position within the text.
@@ -90,7 +88,7 @@ class Pregex():
         for match in self.__iterate_match_objects(text):
             yield (match.group(0), *match.span())
 
-    def iterate_groups(self, text: str, include_empty: bool = True) -> Iterator[tuple[str]]:
+    def iterate_groups(self, text: str, include_empty: bool = True) -> _Iterator[tuple[str]]:
         '''
         Generates any tuples of captured groups that may have occured \
         due to this pattern matching with 'text' one by one.
@@ -102,7 +100,7 @@ class Pregex():
             yield match.groups() if include_empty else \
                 tuple(group for group in match.groups() if group != '')
 
-    def iterate_groups_and_pos(self, text: str, include_empty: bool = True) -> Iterator[list[tuple[str, int, int]]]:
+    def iterate_groups_and_pos(self, text: str, include_empty: bool = True) -> _Iterator[list[tuple[str, int, int]]]:
         '''
         Generates any tuples of captured groups that may have occured \
         due to this pattern matching with 'text' one by one, along with \
@@ -170,8 +168,8 @@ class Pregex():
             that all matches must be replaced.
         '''
         if count < 0:
-            raise NegativeArgumentException(count)
-        return re.sub(str(self), repl, text, count, flags=self.__flags)
+            raise _exceptions.NegativeArgumentException(count)
+        return _re.sub(str(self), repl, text, count, flags=self.__flags)
 
     def split_by_match(self, text: str) -> list[str]:
         '''
@@ -232,7 +230,7 @@ class Pregex():
         elif issubclass(pre.__class__, __class__):
             return pre
         else:
-            raise NeitherStringNorPregexException()
+            raise _exceptions.NeitherStringNorPregexException()
 
     def _add(pre1: str or 'Pregex', pre2: str or 'Pregex') -> 'Pregex':
         return __class__._to_pregex(pre1)._concat(__class__._to_pregex(pre2))
@@ -251,7 +249,7 @@ class Pregex():
         '''
         Returns the string representation of this class instance in a printable format.
         '''
-        return re.sub(r"\\\\", r"\\", repr(self.__pattern)[1:-1])
+        return _re.sub(r"\\\\", r"\\", repr(self.__pattern)[1:-1])
 
     def __add__(self, pre: str or 'Pregex') -> 'Pregex':
         return __class__._add(self, pre)
@@ -281,11 +279,11 @@ class Pregex():
             return n_open == 0
         return False
 
-    def __iterate_match_objects(self, text: str) -> Iterator[re.Match]:
+    def __iterate_match_objects(self, text: str) -> _Iterator[_re.Match]:
         '''
-        Iterates over all matches as objects of type 're.Match'
+        Iterates over all matches as objects of type '_re.Match'
         '''
-        return re.finditer(self.__pattern, text, flags=self.__flags) \
+        return _re.finditer(self.__pattern, text, flags=self.__flags) \
             if self.__compiled is None else self.__compiled.finditer(text)
 
     '''
@@ -313,9 +311,9 @@ class Pregex():
 
     def _exactly(self, n: int) -> 'Pregex':
         if not isinstance(n, int) or isinstance(n, bool):
-            raise NonIntegerArgumentException(n)
+            raise _exceptions.NonIntegerArgumentException(n)
         if n < 1:
-            raise NonPositiveArgumentException(n)
+            raise _exceptions.NonPositiveArgumentException(n)
         elif n == 1:
             return self
         else:
@@ -323,9 +321,9 @@ class Pregex():
 
     def _at_least(self, n: int, is_greedy: bool = True)-> 'Pregex':
         if not isinstance(n, int) or isinstance(n, bool):
-            raise NonIntegerArgumentException(n)
+            raise _exceptions.NonIntegerArgumentException(n)
         if n < 0:
-            raise NegativeArgumentException(n)
+            raise _exceptions.NegativeArgumentException(n)
         elif n == 0:
             return self._indefinite(is_greedy)
         elif n == 1:
@@ -335,9 +333,9 @@ class Pregex():
 
     def _at_most(self, n: int, is_greedy: bool = True) -> 'Pregex':
         if not isinstance(n, int) or isinstance(n, bool):
-            raise NonIntegerArgumentException(n)
+            raise _exceptions.NonIntegerArgumentException(n)
         if n < 1:
-            raise NonPositiveArgumentException(n)
+            raise _exceptions.NonPositiveArgumentException(n)
         elif n == 1:
             return self._optional(is_greedy)
         else:
@@ -345,15 +343,15 @@ class Pregex():
 
     def _at_least_at_most(self, min: int, max: int, is_greedy: bool = True) -> 'Pregex':
         if not isinstance(min, int) or isinstance(min, bool):
-            raise NonIntegerArgumentException(min)
+            raise _exceptions.NonIntegerArgumentException(min)
         if not isinstance(max, int) or isinstance(max, bool):
-            raise NonIntegerArgumentException(max)
+            raise _exceptions.NonIntegerArgumentException(max)
         if min < 0:
-            raise NegativeArgumentException(min)
+            raise _exceptions.NegativeArgumentException(min)
         elif max < 1:
-            raise NonPositiveArgumentException(max)
+            raise _exceptions.NonPositiveArgumentException(max)
         elif max < min:
-            raise MinGreaterThanMaxException(min, max)
+            raise _exceptions.MinGreaterThanMaxException(min, max)
         elif min == max:
             return self._exactly(min)
         else:
@@ -379,14 +377,14 @@ class Pregex():
     '''
     def _capturing_group(self, name: str) -> 'Pregex':
         if not isinstance(name, str):
-            raise NonStringArgumentException()
-        if name != '' and re.fullmatch("[A-Za-z_][A-Za-z_0-9]*", name) is None:
-            raise InvalidCapturingGroupNameException(name)
+            raise _exceptions.NonStringArgumentException()
+        if name != '' and _re.fullmatch("[A-Za-z_][A-Za-z_0-9]*", name) is None:
+            raise _exceptions.InvalidCapturingGroupNameException(name)
         if self.__is_group():
             pattern = self.__pattern.replace('?:', '', 1) if self.__pattern.startswith('(?:') else str(self)
             if name != '':
                 if pattern.startswith('(?P'):
-                    pattern = re.sub('\(\?P<[^>]*>', f'(?P<{name}>', pattern)
+                    pattern = _re.sub('\(\?P<[^>]*>', f'(?P<{name}>', pattern)
                 else:
                     pattern = f"(?P<{name}>{pattern[1:-1]})"
         else:
@@ -396,7 +394,7 @@ class Pregex():
     def _non_capturing_group(self) -> 'Pregex':
         if self.__is_group():
             if self.__pattern.startswith('(?P'):
-                pattern = re.sub('\(\?P<[^>]*>', f'(?:', str(self))
+                pattern = _re.sub('\(\?P<[^>]*>', f'(?:', str(self))
             elif not self.__pattern.startswith('(?:'):
                 pattern = self.__pattern.replace('(', '(?:', 1)
             else:
